
/**
 * 清理搜索模型的空字段
 * @param {Object} model 
 * @param {Array} schemas 
 */
export function clearSearchModel(model, schemas) {
    let ps = {}
    for (let schema of schemas) {
        if (schema.type === 'string') {
            if (model[schema.column] === '') {
                continue
            }
        }
        if (['integer', 'double'].indexOf(schema.type) > -1 && ['boolean', 'bool'].indexOf(schema.format) === -1) {
            if (model[schema.column] === 0) {
                continue
            }
        }
        ps[schema.column] = model[schema.column]
    }
    return ps;
}


/**
 * 判断指定的字段是否显示
 * @param {Object} schema 
 * @param {Object} model 
 */
export function checkSchemaVisible(schema, model) {
    if (!Array.isArray(schema.attribute.visible)) {
        return true
    }
    if (schema.attribute.visible.length <= 0) {
        return true
    }
    for (let cond of schema.attribute.visible) {
        let column = cond['column']
        let values = cond['values']
        if (!column || column === '') {
            continue
        }
        values.map((v) => {
            return v + ''
        })
        let compareValue = model[column]
        if (typeof compareValue === 'undefined') {
            return false
        }
        if (values.indexOf(compareValue + '') === -1) {
            return false
        }
    }
    return true
}


/**
 * 生成规则
 * @param {Object} schema 
 * @param {String} scenario 
 * @returns 
 */
export function generateSchemaRule(schema, scenario) {
    let rules = []
    if (schema.rule.required.indexOf(scenario) > -1) {
        rules.push({
            required: true,
            message: `${schema.label}字段的值不能为空`,
            trigger: 'blur',
        })
    }
    //长度过滤把在线搜索的情况过滤掉
    if (['string', 'text'].indexOf(schema.type) > -1 && schema.format !== 'cascader') {
        rules.push({
            type: 'string',
            message: `${schema.label}字段的值不是有效的字符串`,
            trigger: 'blur',
        })
        if (schema.rule.max > 0 && schema.rule.min > 0) {
            rules.push({
                max: schema.rule.max,
                min: schema.rule.min,
                message: `${schema.label}字段长度必须在${schema.rule.min} - ${schema.rule.max}个字符之间`,
                trigger: 'blur',
            })
        } else if (schema.rule.max > 0) {
            rules.push({
                max: schema.rule.max,
                message: `${schema.label}字段长度不能大于${schema.rule.max}个字符`,
                trigger: 'blur',
            })
        }

    }
    if (['integer', 'decimal', 'number'].indexOf(schema.type) > -1) {
        if (['date', 'datetime', 'timestamp'].indexOf(schema.format) == -1) {
            rules.push({
                type: 'number',
                message: `${schema.label}字段的值不是有效的数字`,
                trigger: 'blur',
            })
            if (schema.rule.min !== 0 && schema.rule.max !== 0) {
                rules.push({
                    max: schema.rule.max,
                    min: schema.rule.min,
                    message: `${schema.label}的值必须在${schema.rule.min} - ${schema.rule.max}之间`,
                    trigger: 'blur',
                })
            } else if (schema.rule.max !== 0) {
                // rules.push({
                //     max: schema.rule.max,
                //     message: `${schema.label}最大值不能大于${schema.rule.max}`,
                //     trigger: 'blur',
                // })
            }
        }
    }
    if (['date', 'datetime', 'timestamp'].indexOf(schema.format) > -1) {
        rules.push({
            type: 'date',
            message: `${schema.label}字段的值是无效的`,
            trigger: 'blur',
        })
    }
    if (schema.rule.regular !== '') {
        rules.push({
            type: 'regexp',
            pattern: schema.rule.regular,
            message: `${schema.label}字段的值不符合规范`,
            trigger: 'blur',
        })
    }
    return rules
}

export function generateSchemaDescription(schema, scenario) {
    if (typeof schema.attribute.description === 'string' && schema.attribute.description !== '') {
        return schema.attribute.description
    }
    let messages = []
    if (schema.rule.required.indexOf(scenario) > -1) {
        messages.push("不能为空")
    }
    if (['string', 'text'].indexOf(schema.type) > -1) {
        if (schema.rule.max > 0 && schema.rule.min > 0) {
            messages.push(`长度必须在${schema.rule.min} - ${schema.rule.max}个字符之间`)
        } else if (schema.rule.max > 0) {
            messages.push(`长度必须小于${schema.rule.max}个字符`)
        }
    }
    if (['integer', 'decimal', 'number'].indexOf(schema.type) > -1) {
        if (schema.rule.max > 0 && schema.rule.min > 0) {
            messages.push(`值必须在${schema.rule.min} - ${schema.rule.max}之间`)
        } else if (schema.rule.max > 0) {
            messages.push(`值必须小于${schema.rule.max}`)
        }
    }
    return messages.join(', ')
}